@@ -87,7 +87,8 @@ class TokenAuthHttpDownloader(HttpDownloader):
         if not self.token and not self.ansible_auth_url:
             return await super()._run(extra_data=extra_data)
         elif self.token and not self.ansible_auth_url:
-            headers = {"Authorization": "Bearer {token}".format(token=self.token)}
+            # https://www.django-rest-framework.org/api-guide/authentication/#tokenauthentication
+            headers = {"Authorization": "Token {token}".format(token=self.token)}
             return await self._run_with_additional_headers(headers)
         else:
             return await self._run_with_token_refresh_and_401_retry()
@@ -157,7 +158,9 @@ class TokenAuthHttpDownloader(HttpDownloader):
                 "refresh_token": self.token,
             }
             url = self.ansible_auth_url
-            async with self.session.post(url, data=form_payload, raise_for_status=True) as response:
+            async with self.session.post(
+                url, data=form_payload, proxy=self.proxy, raise_for_status=True
+            ) as response:
                 token_data = await response.text()
 
             AUTH_TOKEN = json.loads(token_data)["access_token"]
